==> sal-student-1.10.10-20161012.073243-6-sources.jar: com/baijia/tianxiao/sal/student/dto/customFields/fieldTypes/TextCustomFieldType.java <==

/**
 * Baijiahulian.com Inc. Copyright (c) 2014-2016 All Rights Reserved.
 */

package com.baijia.tianxiao.sal.student.dto.customFields.fieldTypes;

import com.baijia.tianxiao.sal.student.enums.CustomFieldType;

import com.google.gson.Gson;
import org.springframework.stereotype.Component;

import lombok.Data;
import lombok.EqualsAndHashCode;

/**
 * little Boy Tell me, where do you dream? Rezar Jul 25, 2016
 */
@Data
@EqualsAndHashCode(callSuper = true)
@Component
public class TextCustomFieldType extends AbstractCustomFieldType<TextCustomFieldType> {

    private String content;

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.baijia.tianxiao.sal.student.dto.customFields.fieldTypes.CustomFieldTypeInterface#objToJson(java.lang.Object)
     */

    @Override
    public String objToJson(TextCustomFieldType obj) {
        return super.toJson(obj);

    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.baijia.tianxiao.sal.student.dto.customFields.fieldTypes.CustomFieldTypeInterface#jsonToObj(java.lang.String)
     */

    @Override
    public TextCustomFieldType jsonToObj(String json) {
        return super.fromJson(json);

    }

    /*
     * (non-Javadoc)
     * 
     * @see com.baijia.tianxiao.sal.student.dto.customFields.fieldTypes.CustomFieldTypeInterface#matchFieldType()
     */

    @Override
    public CustomFieldType matchFieldType() {
        return CustomFieldType.TEXT;

    }

    /*
     * (non-Javadoc)
     * 
     * @see com.baijia.tianxiao.sal.student.dto.customFields.fieldTypes.CustomFieldTypeInterface#instance()
     */

    @Override
    public CustomFieldTypeInterface<TextCustomFieldType> instance() {
        return new TextCustomFieldType();
    }


    public static void main(String[] args) {
        String str = "{\"content\":\"\"}";
        Gson gson = new Gson();
        gson.fromJson(str,TextCustomFieldType.class);
    }
}

==> sal-student-2.31.0-20170731.032805-23-sources.jar: com/baijia/tianxiao/sal/student/dto/customFields/fieldTypes/TextCustomFieldType.java <==

/**
 * Baijiahulian.com Inc. Copyright (c) 2014-2016 All Rights Reserved.
 */

package com.baijia.tianxiao.sal.student.dto.customFields.fieldTypes;

import com.baijia.tianxiao.sal.student.enums.CustomFieldType;

import com.google.gson.Gson;
import org.springframework.stereotype.Component;

import lombok.Data;
import lombok.EqualsAndHashCode;

/**
 *  @say little Boy, don't be sad.
 *  @name Rezar
 *  @time Nov 23, 2016
 *  @Desc this guy is too lazy, nothing left.
 */
@Data
@EqualsAndHashCode(callSuper = true)
@Component
public class TextCustomFieldType extends AbstractCustomFieldType<TextCustomFieldType> {

    private String content;

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.baijia.tianxiao.sal.student.dto.customFields.fieldTypes.CustomFieldTypeInterface#objToJson(java.lang.Object)
     */

    @Override
    public String objToJson(TextCustomFieldType obj) {
        return super.toJson(obj);

    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.baijia.tianxiao.sal.student.dto.customFields.fieldTypes.CustomFieldTypeInterface#jsonToObj(java.lang.String)
     */

    @Override
    public TextCustomFieldType jsonToObj(String json) {
        return super.fromJson(json);

    }

    /*
     * (non-Javadoc)
     * 
     * @see com.baijia.tianxiao.sal.student.dto.customFields.fieldTypes.CustomFieldTypeInterface#matchFieldType()
     */

    @Override
    public CustomFieldType matchFieldType() {
        return CustomFieldType.TEXT;

    }

    /*
     * (non-Javadoc)
     * 
     * @see com.baijia.tianxiao.sal.student.dto.customFields.fieldTypes.CustomFieldTypeInterface#instance()
     */

    @Override
    public CustomFieldTypeInterface<TextCustomFieldType> instance() {
        return new TextCustomFieldType();
    }


    public static void main(String[] args) {
        String str = "{\"content\":\"\"}";
        Gson gson = new Gson();
        gson.fromJson(str,TextCustomFieldType.class);
    }
}
